==========================
Example Images Gallery
==========================

Aydin comes with handful of example images. Along with some datasets that
we generated at Chan Zuckerberg Biohub, we have many datasets from our
collaborators.



.. raw:: html

   <iframe src="https://docs.google.com/document/d/e/2PACX-1vQTTVyBejyjjPiMdvitQ_AKFkYfDUQJFILtfzdzQe1ufzK0jShuDcIRcrL538yFoZhz4V_swxaK_dxx/pub?embedded=true" height="6180" width="720"></iframe>

